@@ -21,19 +21,15 @@ class Kaptan(object):
         self.configuration_data = dict()
         self.handler = self.HANDLER_MAP[handler]()
 
-    def get(self, config_key):
-        return self.configuration_data.get(config_key)
-
     def upsert(self, key, value):
         self.configuration_data.update({key: value})
-
         return self
 
     def import_config(self, value):
         self.configuration_data = self.handler.load(value)
         return self
 
-    def get(self, key):
+    def get(self, key, default=None):
         current_data = self.configuration_data
         for chunk in key.split('.'):
             try:
@@ -47,8 +43,15 @@ class Kaptan(object):
 
                     return current_data[chunk]
                 else:
-                    raise error
+                    # for multi dimensional configs like foo.bar.baz
+                    if default:
+                        return default
+                    raise KeyError(key)
 
+        if current_data == {}:
+            if default:
+                return default
+            raise KeyError(key)
         return current_data
 
     def export(self, handler=None):
